<?php

namespace Services;

use Util\SupUtilities;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class AFProcessService
{

    protected $connection;
    const CDFILLANC = '9999';

    public function __construct(SupUtilities $supUtilities, $entityManager)
    {
        $this->supUtilities = $supUtilities;
        $this->connection = $entityManager->getConnection();
    }

    public function getSupplierName($cdSupplier)
    {
        $query = "SELECT NMFANTFORN FROM FORNECEDOR WHERE CDFORNECED = :P_CDFORNECED";
        $param = ['P_CDFORNECED' => $cdSupplier];
        return $this->supUtilities->crud($query, $param)[0]['NMFANTFORN'];
    }

    public function setMessageAF($message, $dataToSave, $nrMensAutFor)
    {
        $query = "INSERT INTO MENSAUTF (NRMENSAUTFOR, CDFILLANC, NRAUTOFORN, DSMENSAF, CDFILDEST) VALUES (:P_NRMENSAUTFOR, :P_CDFILLANC, :P_NRAUTOFORN, :P_DSMENSAF, :P_CDFILDEST)";
        $params = [
            'P_NRMENSAUTFOR' => $nrMensAutFor,
            'P_CDFILLANC' => self::CDFILLANC,
            'P_NRAUTOFORN' => $dataToSave['nrAutoForn'],
            'P_DSMENSAF' => $message,
            'P_CDFILDEST' => $dataToSave['cdFildest'],
        ];
        $this->supUtilities->crud($query, $params);
    }

    public function updateAF($usrNrImportAf, $dateToSave)
    {
        $query = "UPDATE AUTOFORNE SET USR_NRIMPORTAF = :P_USR_NRIMPORTAF WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN";
        $params = [
            'P_USR_NRIMPORTAF' => $usrNrImportAf,
            'P_CDFILDEST' => $dateToSave['cdFildest'],
            'P_CDFILLANC' => self::CDFILLANC,
            'P_NRAUTOFORN' => $dateToSave['nrAutoForn'],
        ];
        $this->supUtilities->crud($query, $params);
    }

    public function setLogImport($importAFCode, $cdFildest, $orderDate, $cdProduct, $error)
    {
        $query = "INSERT INTO LOGIMPITEMAUTF (USR_NRIMPORTAF, CDFILDEST, CDPRODUTO, DTPROGENTAF, DTIMPITEMAUTF, DSERROIMPORTAF) VALUES (:P_USR_NRIMPORTAF, :P_CDFILDEST, :P_CDPRODUTO, TO_DATE(:P_DTPROGENTAF, 'DD/MM/YYYY'), SYSDATE, :P_DSERROIMPORTAF)";
        $params = [
            'P_USR_NRIMPORTAF' => $importAFCode,
            'P_CDFILDEST' => $cdFildest,
            'P_CDPRODUTO' => $cdProduct,
            'P_DTPROGENTAF' => $orderDate,
            'P_DSERROIMPORTAF' => $error
        ];
        $this->supUtilities->crud($query, $params);
    }

    public function deleteLogImport($importAFCode, $cdFildest, $orderDate)
    {
        $query = "DELETE FROM LOGIMPITEMAUTF WHERE USR_NRIMPORTAF = :P_USR_NRIMPORTAF AND CDFILDEST = :P_CDFILDEST AND TO_CHAR(DTPROGENTAF, 'DD/MM/YYYY') = :P_DTPROGENTAF";
        $params = [
            'P_USR_NRIMPORTAF' => $importAFCode,
            'P_CDFILDEST' => $cdFildest,
            'P_DTPROGENTAF' => $orderDate
        ];
        $this->supUtilities->crud($query, $params);
    }

    public function executeProcedureFechamentoAF($dataToSave)
    {
        try {
            $procedure = new StoredProcedure($this->connection, 'FECHAMENTO_AF');
            $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $dataToSave['cdFildest'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, self::CDFILLANC, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $dataToSave['nrAutoForn'], Param::PARAM_TYPE_STR));
            $procedure->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }

}
